package TP2;


import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;
import org.postgresql.ds.PGPoolingDataSource;

public class ChangePasswordServlet extends HttpServlet {

	
	private static Logger _log = null;
	private PGPoolingDataSource source = null;
	
	
	
	public void init() throws ServletException {
		//get the path to the loggerPropertie file inside the servlet
	    String loggerProperties = this.getServletContext().getInitParameter("loggerProperties");
		loggerProperties = getServletContext().getRealPath("/") + loggerProperties;
		//load the configuration for this application's loggers using the
		// servletLog.properties file
		PropertyConfigurator.configure(loggerProperties);
		//create the logger for this servlet class
		//it will use the configuration for the logger com.java2s.LoggerServlet
		//or inherit from the logger com.java2s if one exists, and so on
		_log = Logger.getLogger(this.getClass());


		_log.info(this.getClass().getName()+" started.");
		 //display a DEBUG level message
	    _log.debug("Sending a DEBUG message");
	    //display an INFO level message
	    _log.info("Sending an INFO message");
	    //display an ERROR level message
	    _log.error("Sending an ERROR message");
	    
	    String database = this.getInitParameter("database");
		String login = this.getServletContext().getInitParameter("login");
		String password = this.getServletContext().getInitParameter("password");
		String server = this.getInitParameter("server");
		String maxConnections = this.getInitParameter("maxConnections");
		
		
		source = new PGPoolingDataSource();
		source.setDataSourceName(this.getClass()+"ServletDataSource");
		source.setServerName(server);
		source.setDatabaseName(database);
		source.setUser(login);
		source.setPassword(password);
		source.setMaxConnections(Integer.parseInt(maxConnections));
		_log.info("Opened a connectivity on DB : "+source.getDataSourceName());
		
	}

	public void destroy() {
		
		_log.info("Closing the connection pool : "+source.getDataSourceName());
		source.close();
		_log.info("Closed the connection ");

	}

	public void doGet(HttpServletRequest request, HttpServletResponse response)
			throws IOException {
	   
		//check the parameters
		if (! request.getParameter("NewPassword").equals(request.getParameter("NewPassword2"))){
			
			try {
				request.setAttribute("errorMessage", "Le mot de passe doit etre entr&eacute; deux fois de facon identique");
				//_log.info(request.getAttribute("errorMessage"));	
				request.getRequestDispatcher("accueil.jsp").forward(request, response);
			} catch (Exception ex) {
				ex.printStackTrace();
			}
			return;
		}
		//do the password update
		User currentUser = (User) request.getSession().getAttribute("currentUser");
		_log.info(currentUser);		
		
		int nbUpdates = update (currentUser, request.getParameter("NewPassword"));
		
		//set an error message if necessary
		if (nbUpdates!=1) {
			request.setAttribute("errorMessage", "Echec de la mise a jour du mot de passe");
		} 

		//forward to accueil
		try {
			request.getRequestDispatcher("accueil.jsp").forward(request, response);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
		
	}

	/**
	 * Do the user update on the database
	 * @param u : User to update in the database Servlet	
	 * @param password : new password of the user
	 * @return the number of update. 1 is OK, else, something is wrong
	 */
	protected int update(User u, String password){
		int nbUpdates = 0;
		Connection conn = null;
		try {
			conn = source.getConnection();
			conn.setAutoCommit(false);
			
			String query = "UPDATE gens SET password='"+password+"' WHERE login='"+u.getLogin()+"'";
			Statement stmt = conn.createStatement();
			nbUpdates = stmt.executeUpdate(query);
		    
			stmt.close();
			conn.commit();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			_log.error(e.getMessage());
			try {
				conn.rollback();
			} catch (SQLException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
				_log.error(e1.getMessage());
			}
		} finally {
			if (conn != null) {
				try { 
					conn.close(); 
				} catch (SQLException e) {
					_log.error(e.getMessage());
				}
			}
	    }
		return nbUpdates;
	}
	
	public void doPost(HttpServletRequest request, HttpServletResponse response)
			throws IOException {
		doGet(request, response);
	}


}
