package TPExamen;


import java.io.IOException;
import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;
import org.postgresql.ds.PGPoolingDataSource;

public class QuartiersServlet extends HttpServlet {

	
	private static Logger _log = null;
	private PGPoolingDataSource source = null;
	
	String explanation;
	
	
	public void init() throws ServletException {
		//get the path to the loggerPropertie file inside the servlet
	    String loggerProperties = this.getServletContext().getInitParameter("loggerProperties");
		loggerProperties = getServletContext().getRealPath("/") + loggerProperties;
		//load the configuration for this application's loggers using the
		// servletLog.properties file
		PropertyConfigurator.configure(loggerProperties);
		//create the logger for this servlet class
		//it will use the configuration for the logger com.java2s.LoggerServlet
		//or inherit from the logger com.java2s if one exists, and so on
		_log = Logger.getLogger(this.getClass());


		_log.info(this.getClass().getName()+" started.");
		 //display a DEBUG level message
	    _log.debug("Sending a DEBUG message");
	    //display an INFO level message
	    _log.info("Sending an INFO message");
	    //display an ERROR level message
	    _log.error("Sending an ERROR message");
	    
	    String database = this.getInitParameter("database");
		String login = this.getServletContext().getInitParameter("login");
		String password = this.getServletContext().getInitParameter("password");
		String server = this.getInitParameter("server");
		String maxConnections = this.getInitParameter("maxConnections");
		
		
		source = new PGPoolingDataSource();
		source.setDataSourceName("ServletDataSource_"+this.getServletName());
		source.setServerName(server);
		source.setDatabaseName(database);
		source.setUser(login);
		source.setPassword(password);
		source.setMaxConnections(Integer.parseInt(maxConnections));
		_log.info("Opened a connectivity on DB : "+source.getDataSourceName());
		
	}

	public void destroy() {
		
		_log.info("Closing the connection pool : "+source.getDataSourceName());
		source.close();
		_log.info("Closed the connection ");

	}

	public void doGet(HttpServletRequest request, HttpServletResponse response)
			throws IOException {
				
		
		
		response.setContentType("text/html");
		PrintWriter pw = response.getWriter();
		pw.print("<html>");
		pw.print("<body bgcolor=\"white\">");
		pw.print("<head>");
		pw.print("<title>Bonjour, vous habitez Grenoble</title>");
		pw.print("</head>");
		pw.print("<body>");
		
		pw.println("<h2>Bonjour, vous habitez Grenoble</h2>");
		//récupérer le nom du quartier choisi
		String nomQuartier = request.getParameter("quartierChoisi");
		//faites le afficher s'il est non null
		if (nomQuartier !=null ){
			pw.println("<h2>Dans le quartier : "+nomQuartier+"</h2>");
		} else {
			pw.println("<h2>Voulez vous choisir votre quartier ?</h2>");
		}
		
		pw.print("<br/>");
		pw.println("<table><tr>");
		pw.println("<td>Liste des quartiers</td>");

		//écrivez l'appel à la méthode qui récupère les noms des quartiers
		ArrayList<Quartier> liste_des_quartiers = allQuartiers();
		//affichez un formulaire qui propose une liste de choix
		pw.println("<form action=\"quartierDescription\" method=\"post\">");
		//ici un input de type select
		pw.println("<td><select size=\"1\" name=\"quartierChoisi\">");
		for (int i=0; i<liste_des_quartiers.size(); i++){
			Quartier q = liste_des_quartiers.get(i);
			pw.println("<option value=\""+q.getName()+"\">"+q.getName()+"</option>");	
		}
		pw.println("</select></td>");
		pw.println("</tr>");
		pw.println("<tr>");
		pw.println("<td>Submit</td>");
		pw.println("<td><input type=\"submit\" value=\"Envoyer\"/></td>");
		pw.println("<tr>");
		pw.println("<tr>");
		pw.println("<td>Reset</td>");
		pw.println("<td><input type=\"reset\" value=\"Annuler\"/></td>");
		pw.println("<tr>");

	
		pw.println("</form>");

		pw.println("</table>");
		pw.print("</body>");
		pw.println("</html>");
		
		
	}

	

	public ArrayList<Quartier> allQuartiers() {
		ArrayList<Quartier> allQuartiers = new ArrayList<Quartier>();
		Connection conn = null;
		try {
			//récupérer une connection depuis la source
			conn = source.getConnection();
			//passer en mode transactionnel sur la connection:
			conn.setAutoCommit(false);
			
			//écrivez votre requète SQL
			String query = "SELECT quartier from quartiers";
			//créer un objet Statement stmt
			Statement stmt = conn.createStatement();
			//faites exécuter la requète, et récupérer le résultat dans ResultSet rs
			ResultSet rs =  stmt.executeQuery(query);

			while (rs.next()) {
				//récupérer le nom du quartier dans le result set
				String nom = rs.getString("quartier");
				//créer un bean Quartier
				Quartier q = new Quartier();
				//ajouter le nom du quartier dans le bean (bean.setXXX(nom))
				q.setName(nom);
				//ajouter le bean à la liste des quartiers
				allQuartiers.add(q);
			}

			//fermer rs
			rs.close();
			//fermer stmt
			stmt.close();
			//sauver les modifications
			conn.commit();
		} catch (SQLException e) {
			e.printStackTrace();
			//faites un log de niveau erreur avec l'exception
			_log.error(e.getMessage());
			explanation = e.getMessage();

			try {
				//annulez la transaction
				conn.rollback();
			} catch (SQLException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
				_log.error(e1.getMessage());
			}
		} finally {
			if (conn != null) {
				try { 
					//fermer la connection
					conn.close(); 
				} catch (SQLException e) {
					_log.error(e.getMessage());
				}
			}
	    }
		return allQuartiers;		
	}

	
	
	public void doPost(HttpServletRequest request, HttpServletResponse response)
			throws IOException {
		doGet(request, response);
	}


}
